# autoloader
The autoloader from NewPro LLC is a device that attaches to the side loading port of a TEM or SEM.  Instead of the normal sample holder, which is loaded manually one sample at a time, the autoloader is a motorized device that can load a dozen or more (depends on configuration) samples at the touch of a button.

# The Library
This project is a native Python library for commanding the autoloader.  It can be integrated into other applications to coordinate the loading of samples with the operation of the microscope.  A .NET assembly is also available which serves the same purpose.

# Example
Refer to `basic_test.py`.
